==> swagger-starter-1.1.2-sources.jar: digital/nedra/commons/starter/swagger/SwaggerAutoConfiguration.java <==
/*
 * Copyright 2022 Nedra Team
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package digital.nedra.commons.starter.swagger;

import digital.nedra.commons.starter.common.config.properties.SwaggerProperties;
import javax.annotation.PostConstruct;
import lombok.extern.slf4j.Slf4j;
import org.springframework.boot.autoconfigure.AutoConfigureOrder;
import org.springframework.boot.context.properties.EnableConfigurationProperties;
import org.springframework.context.annotation.ComponentScan;
import org.springframework.context.annotation.Configuration;
import org.springframework.context.annotation.PropertySource;
import org.springframework.core.Ordered;

@Configuration
@ComponentScan
@PropertySource(value = "classpath:swagger-starter.properties", encoding = "UTF-8")
@Slf4j
@EnableConfigurationProperties(value = {SwaggerProperties.class})
@AutoConfigureOrder(Ordered.HIGHEST_PRECEDENCE)
public class SwaggerAutoConfiguration {
  @PostConstruct
  public void init() {
    log.info("Starter: swagger-starter started");
  }
}

==> swagger-starter-2.0.0-sources.jar: digital/nedra/commons/starter/swagger/SwaggerAutoConfiguration.java <==
/*
 * Copyright 2022 Nedra Team
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package digital.nedra.commons.starter.swagger;

import digital.nedra.commons.starter.common.config.properties.SwaggerProperties;
import jakarta.annotation.PostConstruct;
import lombok.extern.slf4j.Slf4j;
import org.springframework.boot.autoconfigure.AutoConfigureOrder;
import org.springframework.boot.context.properties.EnableConfigurationProperties;
import org.springframework.context.annotation.ComponentScan;
import org.springframework.context.annotation.Configuration;
import org.springframework.context.annotation.PropertySource;
import org.springframework.core.Ordered;

@Configuration
@ComponentScan
@PropertySource(value = "classpath:swagger-starter.properties", encoding = "UTF-8")
@Slf4j
@EnableConfigurationProperties(value = {SwaggerProperties.class})
@AutoConfigureOrder(Ordered.HIGHEST_PRECEDENCE)
public class SwaggerAutoConfiguration {
  @PostConstruct
  public void init() {
    log.info("Starter: swagger-starter started");
  }
}
